@@ -8,7 +8,7 @@ use PPIx::Regexp;
 use base qw( Perl::Critic::Policy );
 
 # ABSTRACT: Prohibit non-ASCII \d in regular expressions
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 use constant DESC => 'Using non-ASCII \d';
@@ -31,6 +31,10 @@ sub violates
   # if the whole expression uses /a then we are in the clear.
   return if $mods{'a'};
 
+  # if the user has explicitly specified the /u modifier then
+  # we should assume that they want unicode digits.  Done.
+  return if $mods{'u'};
+
   my $re = PPIx::Regexp->new($elem->content);
   my $ccs = $re->find('PPIx::Regexp::Token::CharClass');
   return unless $ccs;
@@ -57,17 +61,21 @@ Perl::Critic::Policy::Plicease::ProhibitUnicodeDigitInRegexp - Prohibit non-ASCI
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
 The character class C<\d> in a regular expression matches all unicode digit character, which
 might not be what you expect if you are testing if a string can be used as a number in Perl.
 Instead use either C<[0-9]>, or if you are on Perl 5.14 or better you can use the C</a>
-modifier.
+modifier.  This policy allows C<\d> in expressions with an explicit C</u> modifier (normally
+on by default), as it indicates that the code is expecting Unicode semantics, including Unicode
+digits.
 
  /\d/;      # not ok
  /\d/a;     # ok
+ /\d/u;     # ok
+ /[0-9]/;   # ok
 
 =head1 AFFILIATION
 
@@ -79,8 +87,9 @@ This policy is not configurable except for the standard options.
 
 =head1 CAVEATS
 
-This is a policy that should not be applied toward all applications without some thought.
-This is generally true for all L<Perl::Critic> policies, but especially so for this policy.
+This is not a general policy, and should not be applied toward all applications without
+some thought.  This is frequently true for L<Perl::Critic> policies, but especially so
+for this policy.
 
 In the general the ability to match against unicode digits is a useful ability, and doesn't
 constitute bad code.  Some applications don't ever need to match non-ASCII digit characters,
@@ -89,7 +98,7 @@ and incorrectly rely on C<\d> to validate as a number.
 This policy doesn't take into account using the L<re> pragma.
 
  use re '/a';
-
+ 
  /\d/;  # (still) not ok
 
 =head1 AUTHOR
